"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_eslint_1 = require("@typescript-eslint/utils/dist/ts-eslint");
const memoizeComponent_1 = __importDefault(require("../../rules/memoizeComponent"));
const ruleTester = new ts_eslint_1.RuleTester({
    parserOptions: {
        ecmaFeatures: {
            jsx: true,
        },
    },
    parser: require.resolve('@typescript-eslint/parser'),
});
ruleTester.run('memoize-component', memoizeComponent_1.default, {
    valid: [
        {
            code: `
                const Component = () => {
                    return <div>Something</div>;
                };

                export default memo(component);
            `,
        },
        {
            code: `
                const Component = memo(() => {
                    return <div>Something</div>;
                });

                export default Component;
            `,
        },
        {
            code: `
                export const Component = memo(() => {
                    return <div>Something</div>;
                });
            `,
        },
        {
            code: `
                export const Component = memo(forwardRef(() => {
                    return <div>Something</div>;
                }));
            `,
        },
        {
            code: `
                export const nonComponentFunction = () => {
                    return <div>Something</div>;
                };
            `,
        },
        {
            code: `
                const nonComponentFunction = () => {
                    return <div>Something</div>;
                };

                export default nonComponentFunction;
            `,
        },
        {
            code: `
                const NonExportedComponent = memo(() => {
                    return <div>Something</div>;
                });
            `,
        },
    ],
    invalid: [
        {
            code: `
                const Component = () => {
                    return <div>Something</div>;
                };

                export default Component;
            `,
            errors: [{ messageId: 'general' }],
            output: `
                const Component = () => {
                    return <div>Something</div>;
                };

                export default memo(Component);
            `,
        },
        {
            code: `
                export const Component = () => {
                    return <div>Something</div>;
                };
            `,
            errors: [{ messageId: 'general' }],
            output: `
                export const Component = memo(() => {
                    return <div>Something</div>;
                });
            `,
        },
        {
            code: `
                export const Component = forwardRef(() => {
                    return <div>Something</div>;
                });
            `,
            errors: [{ messageId: 'general' }],
            output: `
                export const Component = memo(forwardRef(() => {
                    return <div>Something</div>;
                }));
            `,
        },
        {
            code: `
                const NonExportedComponent = () => {
                    return <div>Something</div>;
                };
            `,
            errors: [{ messageId: 'general' }],
            output: `
                const NonExportedComponent = memo(() => {
                    return <div>Something</div>;
                });
            `,
        },
    ],
});
